==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FlowSchemaFluentImpl<A extends FlowSchemaFluent<A>> extends BaseFluent<A> implements FlowSchemaFluent<A>{
  public FlowSchemaFluentImpl() {
  }
  public FlowSchemaFluentImpl(FlowSchema instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private FlowSchemaSpecBuilder spec;
  private FlowSchemaStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public FlowSchemaFluent.MetadataNested<A> withNewMetadata() {
    return new FlowSchemaFluentImpl.MetadataNestedImpl();
  }
  public FlowSchemaFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new FlowSchemaFluentImpl.MetadataNestedImpl(item);
  }
  public FlowSchemaFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public FlowSchemaSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(FlowSchemaSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new FlowSchemaSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public FlowSchemaFluent.SpecNested<A> withNewSpec() {
    return new FlowSchemaFluentImpl.SpecNestedImpl();
  }
  public FlowSchemaFluent.SpecNested<A> withNewSpecLike(FlowSchemaSpec item) {
    return new FlowSchemaFluentImpl.SpecNestedImpl(item);
  }
  public FlowSchemaFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public FlowSchemaFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new FlowSchemaSpecBuilder().build());
  }
  public FlowSchemaFluent.SpecNested<A> editOrNewSpecLike(FlowSchemaSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public FlowSchemaStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(FlowSchemaStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new FlowSchemaStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public FlowSchemaFluent.StatusNested<A> withNewStatus() {
    return new FlowSchemaFluentImpl.StatusNestedImpl();
  }
  public FlowSchemaFluent.StatusNested<A> withNewStatusLike(FlowSchemaStatus item) {
    return new FlowSchemaFluentImpl.StatusNestedImpl(item);
  }
  public FlowSchemaFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public FlowSchemaFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new FlowSchemaStatusBuilder().build());
  }
  public FlowSchemaFluent.StatusNested<A> editOrNewStatusLike(FlowSchemaStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FlowSchemaFluentImpl that = (FlowSchemaFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<FlowSchemaFluent.MetadataNested<N>> implements FlowSchemaFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends FlowSchemaSpecFluentImpl<FlowSchemaFluent.SpecNested<N>> implements FlowSchemaFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(FlowSchemaSpec item) {
      this.builder = new FlowSchemaSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new FlowSchemaSpecBuilder(this);
    }
    FlowSchemaSpecBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends FlowSchemaStatusFluentImpl<FlowSchemaFluent.StatusNested<N>> implements FlowSchemaFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(FlowSchemaStatus item) {
      this.builder = new FlowSchemaStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new FlowSchemaStatusBuilder(this);
    }
    FlowSchemaStatusBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FlowSchemaFluentImpl<A extends FlowSchemaFluent<A>> extends BaseFluent<A> implements FlowSchemaFluent<A>{
  public FlowSchemaFluentImpl() {
  }
  public FlowSchemaFluentImpl(FlowSchema instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private FlowSchemaSpecBuilder spec;
  private FlowSchemaStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public FlowSchemaFluentImpl.MetadataNested<A> withNewMetadata() {
    return new FlowSchemaFluentImpl.MetadataNestedImpl();
  }
  public FlowSchemaFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new FlowSchemaFluentImpl.MetadataNestedImpl(item);
  }
  public FlowSchemaFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public FlowSchemaFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public FlowSchemaFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public FlowSchemaSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(FlowSchemaSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new FlowSchemaSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public FlowSchemaFluentImpl.SpecNested<A> withNewSpec() {
    return new FlowSchemaFluentImpl.SpecNestedImpl();
  }
  public FlowSchemaFluentImpl.SpecNested<A> withNewSpecLike(FlowSchemaSpec item) {
    return new FlowSchemaFluentImpl.SpecNestedImpl(item);
  }
  public FlowSchemaFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public FlowSchemaFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new FlowSchemaSpecBuilder().build());
  }
  public FlowSchemaFluentImpl.SpecNested<A> editOrNewSpecLike(FlowSchemaSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public FlowSchemaStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(FlowSchemaStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new FlowSchemaStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public FlowSchemaFluentImpl.StatusNested<A> withNewStatus() {
    return new FlowSchemaFluentImpl.StatusNestedImpl();
  }
  public FlowSchemaFluentImpl.StatusNested<A> withNewStatusLike(FlowSchemaStatus item) {
    return new FlowSchemaFluentImpl.StatusNestedImpl(item);
  }
  public FlowSchemaFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public FlowSchemaFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new FlowSchemaStatusBuilder().build());
  }
  public FlowSchemaFluentImpl.StatusNested<A> editOrNewStatusLike(FlowSchemaStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlowSchemaFluentImpl that = (FlowSchemaFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<FlowSchemaFluentImpl.MetadataNested<N>> implements FlowSchemaFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends FlowSchemaSpecFluentImpl<FlowSchemaFluentImpl.SpecNested<N>> implements FlowSchemaFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(FlowSchemaSpec item) {
      this.builder = new FlowSchemaSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new FlowSchemaSpecBuilder(this);
    }
    FlowSchemaSpecBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends FlowSchemaStatusFluentImpl<FlowSchemaFluentImpl.StatusNested<N>> implements FlowSchemaFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(FlowSchemaStatus item) {
      this.builder = new FlowSchemaStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new FlowSchemaStatusBuilder(this);
    }
    FlowSchemaStatusBuilder builder;
    public N and() {
      return (N) FlowSchemaFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
